# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-10-01 03:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('flow', '0021_collection_tags'),
    ]

    operations = [
        migrations.AddField(
            model_name='process',
            name='entity_descriptor_schema',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='process',
            name='entity_input',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='process',
            name='entity_type',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='entity',
            name='type',
            field=models.CharField(blank=True, db_index=True, max_length=100, null=True),
        ),
    ]



"""Storage viewset."""
from rest_framework import mixins, viewsets

from resolwe.flow.models import Storage
from resolwe.flow.serializers import StorageSerializer


class StorageViewSet(mixins.RetrieveModelMixin,
                     viewsets.GenericViewSet):
    """API view for :class:`Storage` objects."""

    queryset = Storage.objects.all().prefetch_related('contributor')
    serializer_class = StorageSerializer
